@@ -1,11 +1,8 @@
-# This module normally gets compiled into a c module to improve the speed.
+# This module normally gets compiled into a C module to improve the speed.
 # Tested with Shedskin 0.6
 # In case the module can not be compiled or the file lib/mylib.so is missing,
 # python will jump back and use this file (mylib.py) instead.
-# This work the same, but might be slower.
-# 19. Nov. 2010, George Ruinelli
-
-
+# This works the same, but might be slower.
 
 
 def IsCompiled():
@@ -18,7 +15,7 @@ def IsCompiled():
 
 
 
-def sleep_filter(ar, l, filter,  shift, scale):
+def sleep_filter(ar, l, filter,  shift, scale, max, min):
     len_filter=len(filter)
 
     ar_ret=[0]*(l+len_filter)
@@ -30,7 +27,14 @@ def sleep_filter(ar, l, filter,  shift, scale):
             ar_ret[i+p-shift] = ar_ret[i+p-shift] + value*filter[p]
 
     for i in range(0, l-1): #loop arrData
-        ar_ret[i]=ar_ret[i]/(scale*100)
+        value=ar_ret[i] / (scale*100) #autoscale
+
+        if(value > max): #check range over/unterrun
+            ar_ret[i] = max #-int(random.uniform(1, 2))
+        elif(value < min):
+            ar_ret[i] =min
+        else:
+            ar_ret[i]=value
 
     return ar_ret
 
@@ -43,4 +47,4 @@ if __name__ == '__main__':
     IsCompiled()
     arTest=[1, 2, 3, 4, 5, 6, 7, 8, 9]
     arFiltertest=[1, 2, 3]
-    sleep_filter(arTest, 1, arFiltertest, 1, 20)
+    sleep_filter(arTest, 1, arFiltertest, 1, 20, 120, 13)
